//  Copyright 2009 David Ekholm, Jalbum AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.package net.jalbum.editor;

package DiskUsage;

import java.awt.*;
import javax.swing.*;
import java.util.*;

/**
 * CrushFTP plugin UI
 * @author david
 */
public class GUI extends JPanel {

    public GUI() {
        try {
            //crushftp.handlers.Common.debug(0,"----- Initializing UI for DiskUsage plugin -----");
            jbInit();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }
    Object parent = null;
    private JCheckBox enabled = new JCheckBox("Enabled");
    private JCheckBox debugMode = new JCheckBox("Debug");
    private JCheckBox forceCacheRefresh = new JCheckBox("Force cache refresh");

    public void setParent(Object parent) {
        this.parent = parent;
    }

    void jbInit() throws Exception {
        setLayout(new BorderLayout());
        setBorder(BorderFactory.createEmptyBorder(6,6,6,6));
        forceCacheRefresh.setToolTipText("Use temporarily if cache files for some reason are out of sync.");
        debugMode.setToolTipText("Print calculated disk usage for given path to log");
        JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.LEADING));
        buttonPanel.add(enabled);
        buttonPanel.add(debugMode);
        buttonPanel.add(forceCacheRefresh);

        add(buttonPanel, BorderLayout.NORTH);

        JTextArea description = new JTextArea("This plugin accelerates getting disk usage for given path by storing a cache file called \".du\" in each directory under given path." +
                " Reading the cache file is far faster than listing the directory content. " +
                "To ensure that users can't view or modify the cache file, the plugin also installs filename filters for it.\n\n" +
                "The cache file contains the number of used bytes in that directory alone. It also lists the subdirectories of that directory. " +
                "It is refreshed on demand if it is missing or if the last modified date of its parent directory differs from the last modified date of the cache file. " +
                "The file system ensures that any change to a directory touches the last modified date of the directory. The exception being if a file is updated. " +
                "However CrushFTP ensures that the last modified date of a directory is touched for any operation that affects the directory contents, " +
                "therefore, this way of cacheing disk usage should be tight.\n\n" +
                "Remember to set 'Real File Quota' in order for the plugin to work!\n\n" +
                "Command line usage:\n java -jar DiskUsage.jar [-f | -d] <path>\n" +
                "-f forces refresh and -d deletes all cache files.\n\n" +
                "API usage:\nnet.jalbum.diskusage.DiskUsage.getDiskUsage(File path, boolean forceCacheRefresh);\n\n" +
                "/David Ekholm, Jalbum AB (david@jalbum.net)"
                );

        description.setEditable(false);
        description.setWrapStyleWord(true);
        description.setLineWrap(true);
        description.setOpaque(false);
        Font f = description.getFont();
        description.setFont(f.deriveFont(f.getSize2D()-2));
        description.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder("About"), BorderFactory.createEmptyBorder(6,6,6,6)));
        JPanel descPanel = new JPanel(new BorderLayout());
        descPanel.add(description, BorderLayout.NORTH);
        add(descPanel, BorderLayout.CENTER);

    }

    public Properties getSettings() {
        Properties p = new Properties();
        p.put("enabled", enabled.isSelected() + "");
        p.put("debug", debugMode.isSelected() + "");
        p.put("forceCacheRefresh", forceCacheRefresh.isSelected() + "");
        return p;
    }

    public void setSettings(Properties p) {
        enabled.setSelected(p.getProperty("enabled").equalsIgnoreCase("true"));
        debugMode.setSelected(p.getProperty("debug").equalsIgnoreCase("true"));
        forceCacheRefresh.setSelected(p.getProperty("forceCacheRefresh").equalsIgnoreCase("true"));
    }
}